@@ -1,3 +1,4 @@
-def test_dependencies():
-    from birdy.dependencies import ipywidgets as widgets  # noqa: F401
+# noqa: D100
+def test_dependencies():  # noqa: D103
     from birdy.dependencies import IPython  # noqa: F401
+    from birdy.dependencies import ipywidgets as widgets  # noqa: F401
